from setuptools import setup,find_packages

setup(
    name='zuele',
    version='0.0.1',
    author='ikun',
    author_email='2206490823@qq.com',
    description='Jieba in economy',
    packages=['zuele'],
    package_dir={'zuele':'zuele'},
)
